@@ -13,7 +13,7 @@ from dvc.path_info import CloudURLInfo
 from dvc.remote.base import RemoteBASE
 from dvc.config import Config
 from dvc.exceptions import DvcException
-from dvc.utils import tmp_fname
+from dvc.utils import tmp_fname, format_link
 
 logger = logging.getLogger(__name__)
 FOLDER_MIME_TYPE = "application/vnd.google-apps.folder"
@@ -33,12 +33,11 @@ class GDriveMissedCredentialKeyError(DvcException):
 
 @decorator
 def _wrap_pydrive_retriable(call):
-    from apiclient import errors
     from pydrive2.files import ApiRequestError
 
     try:
         result = call()
-    except (ApiRequestError, errors.HttpError) as exception:
+    except ApiRequestError as exception:
         retry_codes = ["403", "500", "502", "503", "504"]
         if any(
             "HttpError {}".format(code) in str(exception)
@@ -93,7 +92,7 @@ class RemoteGDrive(RemoteBASE):
             raise DvcException(
                 "Please specify Google Drive's client id and "
                 "secret in DVC's config. Learn more at "
-                "https://man.dvc.org/remote/add."
+                "{}.".format(format_link("https://man.dvc.org/remote/add"))
             )
         self.gdrive_user_credentials_path = (
             tmp_fname(os.path.join(self.repo.tmp_dir, ""))
@@ -210,6 +209,7 @@ class RemoteGDrive(RemoteBASE):
             GoogleAuth.DEFAULT_SETTINGS["get_refresh_token"] = True
             GoogleAuth.DEFAULT_SETTINGS["oauth_scope"] = [
                 "https://www.googleapis.com/auth/drive",
+                # drive.appdata grants access to appDataFolder GDrive directory
                 "https://www.googleapis.com/auth/drive.appdata",
             ]
 
